@@ -21,6 +21,7 @@
 #  include <config.h>
 #endif
 #include "pyorbit-private.h"
+#include <sysmodule.h>
 #include <orbit/poa/poa-types.h>
 #ifdef HAVE_ORBIT2_IMODULE
 #  include <ORBitservices/orbit-imodule.h>
@@ -380,7 +381,7 @@ void initORBit(void);
 DL_EXPORT(void)
 initORBit(void)
 {
-    PyObject *mod, *corbamod, *psmod;
+    PyObject *mod, *modules_dict, *corbamod, *psmod;
 
 #define INIT_TYPE(tp) G_STMT_START{ \
     if (!tp.ob_type)  tp.ob_type  = &PyType_Type; \
@@ -407,6 +408,8 @@ initORBit(void)
 
 #undef INIT_TYPE
 
+    modules_dict = PySys_GetObject("modules");
+
     mod = Py_InitModule("ORBit", orbit_functions);
 
     PyModule_AddObject(mod, "orbit_version",
@@ -415,10 +418,19 @@ initORBit(void)
 				     orbit_minor_version,
 				     orbit_micro_version));
 
+    PyModule_AddObject(mod, "__version__",
+		       Py_BuildValue("(iii)",
+				     PYORBIT_MAJOR_VERSION,
+				     PYORBIT_MINOR_VERSION,
+				     PYORBIT_MICRO_VERSION));
+
     PyModule_AddObject(mod, "_PyORBit_API",
 		       PyCObject_FromVoidPtr(&api, NULL));
 
-    corbamod = Py_InitModule("CORBA", corba_functions);
+    corbamod = Py_InitModule("ORBit.CORBA", corba_functions);
+    Py_INCREF(corbamod);
+    PyModule_AddObject(mod, "CORBA", corbamod);
+    PyDict_SetItemString(modules_dict, "CORBA", corbamod);
 
     PyModule_AddObject(corbamod, "TypeCode",
 		       (PyObject *)&PyCORBA_TypeCode_Type);
@@ -439,7 +451,10 @@ initORBit(void)
     register_corba_types();
     add_tc_constants(corbamod);
 
-    psmod = Py_InitModule("PortableServer", portableserver_functions);
+    psmod = Py_InitModule("ORBit.PortableServer", portableserver_functions);
+    Py_INCREF(psmod);
+    PyModule_AddObject(mod, "PortableServer", psmod);
+    PyDict_SetItemString(modules_dict, "PortableServer", psmod);
     PyModule_AddObject(psmod, "POA",
 		       (PyObject *)&PyPortableServer_POA_Type);
     PyModule_AddObject(psmod, "POAManager",
