@@ -151,7 +151,8 @@ pycorba_method_call(PyCORBA_Method *self, PyObject *args, PyObject *kwargs)
 	    item = PyTuple_GetItem(args, argpos++);
 	    if (!pyorbit_marshal_any(&any, item)) {
 		PyErr_Format(PyExc_TypeError, "could not marshal arg '%s'",
-			     imethod->arguments._buffer[i].name);
+			     imethod->arguments._buffer[i].name ?
+			     imethod->arguments._buffer[i].name : "<unknown>");
 		goto cleanup;
 	    }
 	}
@@ -211,7 +212,8 @@ pycorba_method_call(PyCORBA_Method *self, PyObject *args, PyObject *kwargs)
 		pyret = NULL;
 		PyErr_Format(PyExc_TypeError,
 			     "could not demarshal return value '%s'",
-			     imethod->arguments._buffer[i].name);
+			     imethod->arguments._buffer[i].name ?
+			     imethod->arguments._buffer[i].name : "<unknown>");
 		goto cleanup;
 	    }
 	    PyTuple_SetItem(pyret, retpos++, item);
@@ -226,7 +228,8 @@ pycorba_method_call(PyCORBA_Method *self, PyObject *args, PyObject *kwargs)
 		pyret = NULL;
 		PyErr_Format(PyExc_TypeError,
 			     "could not demarshal return value '%s'",
-			     imethod->arguments._buffer[i].name);
+			     imethod->arguments._buffer[i].name ?
+			     imethod->arguments._buffer[i].name : "<unknown>");
 		goto cleanup;
 	    }
 	    PyTuple_SetItem(pyret, retpos++, item);
