@@ -91,10 +91,10 @@ pycorba_orb_list_initial_services(PyCORBA_ORB *self)
     if (pyorbit_check_ex(&ev))
 	return NULL;
 
-    pyret = PyTuple_New(ret->_length);
+    pyret = PyList_New(ret->_length);
     for (i = 0; i < ret->_length; i++) {
 	PyObject *item = PyString_FromString(ret->_buffer[i]);
-	PyTuple_SetItem(pyret, i, item);
+	PyList_SetItem(pyret, i, item);
     }
     CORBA_free(ret);
     return pyret;
